@@ -4,7 +4,7 @@
 	 * Does an export to the screen or as a download.  This checks to
 	 * see if they have pg_dump set up, and will use it if possible.
 	 *
-	 * $Id: dataexport.php,v 1.17.2.3 2005/07/15 08:09:20 chriskl Exp $
+	 * $Id: dataexport.php,v 1.26 2007/07/12 19:26:22 xzilla Exp $
 	 */
 
 	$extensions = array(
@@ -16,35 +16,26 @@
 		'xml' => 'xml'
 	);
 
-	// Prevent timeouts
+	// Prevent timeouts on large exports (non-safe mode only)
 	if (!ini_get('safe_mode')) set_time_limit(0);
 
 	// if (!isset($_REQUEST['table']) && !isset($_REQUEST['query']))
 	// What must we do in this case? Maybe redirect to the homepage?
 
 	// If format is set, then perform the export
-	if (isset($_REQUEST['what'])) {		 
-
+	if (isset($_REQUEST['what'])) {
+		
 		// Include application functions
 		$_no_output = true;
 		include_once('./libraries/lib.inc.php');
-
+		
 		switch ($_REQUEST['what']) {
 			case 'dataonly':
 				// Check to see if they have pg_dump set up and if they do, use that
 				// instead of custom dump code
 				if ($misc->isDumpEnabled()
 						&& ($_REQUEST['d_format'] == 'copy' || $_REQUEST['d_format'] == 'sql')) {
-					$url = 'dbexport.php?mode=database&database=' . urlencode($_REQUEST['database']);
-					$url .= '&what=' . urlencode($_REQUEST['what']);
-					$url .= '&table=' . urlencode($_REQUEST['table']);
-					if ($data->hasSchemas()) $url .= '&schema=' . urlencode($_REQUEST['schema']);
-					$url .= '&d_format=' . urlencode($_REQUEST['d_format']);
-					$url .= '&output=' . urlencode($_REQUEST['output']);
-					if (isset($_REQUEST['d_oids'])) $url .= '&d_oids=' . urlencode($_REQUEST['d_oids']);
-					$url .= "&" . SID;
-					
-					header("Location: {$url}");
+					include('./dbexport.php');
 					exit;
 				}
 				else {
@@ -56,15 +47,7 @@
 				// Check to see if they have pg_dump set up and if they do, use that
 				// instead of custom dump code
 				if ($misc->isDumpEnabled()) {
-					$url = 'dbexport.php?mode=database&database=' . urlencode($_REQUEST['database']);
-					$url .= '&what=' . urlencode($_REQUEST['what']);
-					$url .= '&table=' . urlencode($_REQUEST['table']);
-					if ($data->hasSchemas()) $url .= '&schema=' . urlencode($_REQUEST['schema']);
-					$url .= '&output=' . urlencode($_REQUEST['output']);
-					if (isset($_REQUEST['s_clean'])) $url .= '&s_clean=' . urlencode($_REQUEST['s_clean']);
-					$url .= "&" . SID;
-					
-					header("Location: {$url}");
+					include('./dbexport.php');
 					exit;
 				}
 				else $clean = isset($_REQUEST['s_clean']);
@@ -73,17 +56,7 @@
 				// Check to see if they have pg_dump set up and if they do, use that
 				// instead of custom dump code
 				if ($misc->isDumpEnabled()) {
-					$url = 'dbexport.php?mode=database&database=' . urlencode($_REQUEST['database']);
-					$url .= '&what=' . urlencode($_REQUEST['what']);
-					$url .= '&table=' . urlencode($_REQUEST['table']);
-					if ($data->hasSchemas()) $url .= '&schema=' . urlencode($_REQUEST['schema']);
-					$url .= '&sd_format=' . urlencode($_REQUEST['sd_format']);
-					$url .= '&output=' . urlencode($_REQUEST['output']);
-					if (isset($_REQUEST['sd_clean'])) $url .= '&sd_clean=' . urlencode($_REQUEST['sd_clean']);
-					if (isset($_REQUEST['sd_oids'])) $url .= '&sd_oids=' . urlencode($_REQUEST['sd_oids']);
-					$url .= "&" . SID;
-
-					header("Location: {$url}");
+					include('./dbexport.php');
 					exit;
 				}
 				else {
@@ -118,6 +91,11 @@
 	
 		if (isset($_REQUEST['query'])) $_REQUEST['query'] = trim(urldecode($_REQUEST['query']));
 
+		// Set the schema search path
+		if ($data->hasSchemas() && isset($_REQUEST['search_path'])) {
+			$data->setSearchPath(array_map('trim',explode(',',$_REQUEST['search_path'])));
+		}
+		
 		// Set up the dump transaction
 		$status = $data->beginDump();
 
@@ -135,7 +113,7 @@
 
 			// Execute the query, if set, otherwise grab all rows from the table
 			if (isset($_REQUEST['table']))
-				$rs = &$data->dumpRelation($_REQUEST['table'], $oids);
+				$rs = $data->dumpRelation($_REQUEST['table'], $oids);
 			else
 				$rs = $data->conn->Execute($_REQUEST['query']);
 
@@ -146,13 +124,12 @@
 				echo " FROM stdin;\n";
 				while (!$rs->EOF) {
 					$first = true;
-					while(list($k, $v) = each($rs->f)) {
+					while(list($k, $v) = each($rs->fields)) {
 						// Escape value
-						// addCSlashes converts all weird ASCII characters to octal representation,
-						// EXCEPT the 'special' ones like \r \n \t, etc.
-						$v = addCSlashes($v, "\0..\37\177..\377");
+						$v = $data->escapeBytea($v);
+						
 						// We add an extra escaping slash onto octal encoded characters
-						$v = ereg_replace('\\\\([0-7]{3})', '\\\\\1', $v);
+						$v = preg_replace('/\\\\([0-7]{3})/', '\\\\\1', $v);
 						if ($first) {
 							echo ($v == null) ? '\\N' : $v;
 							$first = false;
@@ -177,7 +154,7 @@
 				if (!$rs->EOF) {
 					// Output header row
 					$j = 0;
-					foreach ($rs->f as $k => $v) {
+					foreach ($rs->fields as $k => $v) {
 						$finfo = $rs->fetchField($j++);
 						if ($finfo->name == $data->id && !$oids) continue;
 						echo "\t\t<th>", $misc->printVal($finfo->name, true), "</th>\r\n";
@@ -187,7 +164,7 @@
 				while (!$rs->EOF) {
 					echo "\t<tr>\r\n";
 					$j = 0;
-					foreach ($rs->f as $k => $v) {
+					foreach ($rs->fields as $k => $v) {
 						$finfo = $rs->fetchField($j++);
 						if ($finfo->name == $data->id && !$oids) continue;
 						echo "\t\t<td>", $misc->printVal($v, true, $finfo->type), "</td>\r\n";
@@ -209,7 +186,7 @@
 					// Output header row
 					$j = 0;
 					echo "\t<header>\n";
-					foreach ($rs->f as $k => $v) {
+					foreach ($rs->fields as $k => $v) {
 						$finfo = $rs->fetchField($j++);
 						$name = htmlspecialchars($finfo->name);
 						$type = htmlspecialchars($finfo->type);
@@ -221,7 +198,7 @@
 				while (!$rs->EOF) {
 					$j = 0;
 					echo "\t\t<row>\n";
-					foreach ($rs->f as $k => $v) {
+					foreach ($rs->fields as $k => $v) {
 						$finfo = $rs->fetchField($j++);
 						$name = htmlspecialchars($finfo->name);
 						if ($v != null) $v = htmlspecialchars($v);
@@ -239,7 +216,7 @@
 					echo "INSERT INTO \"{$_REQUEST['table']}\" (";
 					$first = true;
 					$j = 0;
-					foreach ($rs->f as $k => $v) {
+					foreach ($rs->fields as $k => $v) {
 						$finfo = $rs->fetchField($j++);
 						$k = $finfo->name;
 						// SQL (INSERT) format cannot handle oids
@@ -255,7 +232,7 @@
 							// EXCEPT the 'special' ones like \r \n \t, etc.
 							$v = addCSlashes($v, "\0..\37\177..\377");
 							// We add an extra escaping slash onto octal encoded characters
-							$v = ereg_replace('\\\\([0-7]{3})', '\\\1', $v);
+							$v = preg_replace('/\\\\([0-7]{3})/', '\\\1', $v);
 							// Finally, escape all apostrophes
 							$v = str_replace("'", "''", $v);
 						}
@@ -282,7 +259,7 @@
 				if (!$rs->EOF) {
 					// Output header row
 					$first = true;
-					foreach ($rs->f as $k => $v) {
+					foreach ($rs->fields as $k => $v) {
 						$finfo = $rs->fetchField($k);
 						$v = $finfo->name;
 						if ($v != null) $v = str_replace('"', '""', $v);
@@ -296,7 +273,7 @@
 				}
 				while (!$rs->EOF) {
 					$first = true;
-					foreach ($rs->f as $k => $v) {
+					foreach ($rs->fields as $k => $v) {
 						if ($v != null) $v = str_replace('"', '""', $v);
 						if ($first) {
 							echo ($v == null) ? "\"\\N\"" : "\"{$v}\"";
@@ -321,16 +298,16 @@
 		$status = $data->endDump();
 	}
 	else {
-		if (!isset($msg)) $msg = null;
-		
 		// Include application functions
 		include_once('./libraries/lib.inc.php');
 
-		$misc->printHeader($lang['strexport']);		
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strexport']}</h2>\n";
-		$misc->printMsg($msg);
+		$misc->printHeader($lang['strexport']);
+		$misc->printBody();
+		$misc->printTrail(isset($_REQUEST['subject']) ? $_REQUEST['subject'] : 'database');
+		$misc->printTitle($lang['strexport']);
+		if (isset($msg)) $misc->printMsg($msg);
 
-		echo "<form action=\"{$_SERVER['PHP_SELF']}\" method=\"post\">\n";
+		echo "<form action=\"dataexport.php\" method=\"post\">\n";
 		echo "<table>\n";
 		echo "<tr><th class=\"data\">{$lang['strformat']}:</th><td><select name=\"d_format\">\n";
 		// COPY and SQL require a table
@@ -346,8 +323,8 @@
 		echo "</table>\n";
 
 		echo "<h3>{$lang['stroptions']}</h3>\n";
-		echo "<p><input type=\"radio\" name=\"output\" value=\"show\" checked=\"checked\" />{$lang['strshow']}\n";
-		echo "<br/><input type=\"radio\" name=\"output\" value=\"download\" />{$lang['strdownload']}</p>\n";
+		echo "<p><input type=\"radio\" id=\"output1\" name=\"output\" value=\"show\" checked=\"checked\" /><label for=\"output1\">{$lang['strshow']}</label>\n";
+		echo "<br/><input type=\"radio\" id=\"output2\" name=\"output\" value=\"download\" /><label for=\"output2\">{$lang['strdownload']}</label></p>\n";
 
 		echo "<p><input type=\"hidden\" name=\"action\" value=\"export\" />\n";
 		echo "<input type=\"hidden\" name=\"what\" value=\"dataonly\" />\n";
@@ -355,6 +332,9 @@
 			echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
 		}
 		echo "<input type=\"hidden\" name=\"query\" value=\"", htmlspecialchars(urlencode($_REQUEST['query'])), "\" />\n";
+		if (isset($_REQUEST['search_path'])) {
+			echo "<input type=\"hidden\" name=\"search_path\" value=\"", htmlspecialchars($_REQUEST['search_path']), "\" />\n";
+		}
 		echo $misc->form;
 		echo "<input type=\"submit\" value=\"{$lang['strexport']}\" /></p>\n";
 		echo "</form>\n";
