@@ -2,7 +2,7 @@
 
 	/**
 	 * Translated by Chih-Hsin Lee [chlee@femh.org.tw]
-	 * $Id: chinese-tr.php,v 1.14 2004/07/12 04:18:42 chriskl Exp $
+	 * $Id: chinese-tr.php,v 1.18 2007/04/24 11:43:16 soranzo Exp $
 	 *
 	 *
 	 */
@@ -87,7 +87,7 @@
 	$lang['stradmin'] = '&#31649;&#29702;';
 	$lang['strvacuum'] = '&#28165;&#31354;';
 	$lang['stranalyze'] = '&#20998;&#26512;';
-	$lang['strcluster'] = '&#21474;&#38598;';
+	$lang['strclusterindex'] = '&#21474;&#38598;';
 	$lang['strclustered'] = '&#21474;&#38598;?';
 	$lang['strreindex'] = '&#37325;&#24314;&#32034;&#24341;';
 	$lang['strrun'] = '&#22519;&#34892;';
@@ -126,7 +126,6 @@
 	$lang['strfileimported'] = '&#27284;&#26696;&#24050;&#21295;&#20837;&#12290;';
 
 	// Error handling
-	$lang['strnoframes'] = '&#24744;&#38656;&#29992;&#25903;&#25588;&#26694;&#26550;&#30340;&#28687;&#35261;&#22120;&#28687;&#35261;&#26412;&#31243;&#24335;&#12290;';
 	$lang['strbadconfig'] = '&#24744;&#30340; config.inc.php &#28961;&#25928;&#12290;&#35531;&#21033;&#29992; config.inc.php-dist &#24314;&#31435;&#24744;&#30340; config.inc.php &#27284;&#12290;';
 	$lang['strnotloaded'] = '&#24744;&#30340; PHP &#29872;&#22659;&#26410;&#23433;&#35037;&#24517;&#38656;&#30340;&#36039;&#26009;&#24235;&#25903;&#25588;&#12290;';
 	$lang['strbadschema'] = '&#25351;&#23450;&#20102;&#28961;&#25928;&#30340;&#27169;&#24335; (schema)&#12290;';
@@ -322,7 +321,6 @@
 	$lang['strcachevalue'] = '&#24555;&#21462;&#20540;';
 	$lang['strlogcount'] = '&#30331;&#37636;&#25976;&#37327;';
 	$lang['striscycled'] = '&#24490;&#29872;?';
-	$lang['striscalled'] = '&#34987;&#21628;&#21483;?';
 	$lang['strsequenceneedsname'] = '&#24744;&#38656;&#28858;&#24744;&#30340;&#24207;&#21015;&#21629;&#21517;&#12290;';
 	$lang['strsequencecreated'] = '&#25104;&#21151;&#24314;&#31435;&#26032;&#24207;&#21015;&#12290;';
 	$lang['strsequencecreatedbad'] = '&#24314;&#31435;&#26032;&#24207;&#21015;&#20316;&#26989;&#22833;&#25943;&#12290;'; 
