@@ -4,7 +4,7 @@
 	 * English language file for phpPgAdmin.  Use this as a basis
 	 * for new translations.
 	 *
-	 * $Id: english.php,v 1.183 2008/02/23 16:34:33 ioguix Exp $
+	 * $Id: english.php,v 1.232 2008/02/23 16:34:33 ioguix Exp $
 	 */
 
 	// Language and character set
@@ -133,6 +133,7 @@
 	$lang['strfile'] = 'File';
 	$lang['strfileimported'] = 'File imported.';
 	$lang['strtrycred'] = 'Use these credentials for all servers';
+	$lang['strconfdropcred'] = 'For security reason, disconnecting will destroy your shared login information. Are you sure you want to disconnect ?';
 	$lang['stractionsonmultiplelines'] = 'Actions on multiple lines';
 	$lang['strselectall'] = 'Select all';
 	$lang['strunselectall'] = 'Unselect all';
@@ -179,6 +180,8 @@
 	$lang['strcannotdumponwindows'] = 'Dumping of complex table and schema names on Windows is not supported.';
 	$lang['strinvalidserverparam'] = 'Attempt to connect with invalid server parameter, possibly someone is trying to hack your system.'; 
 	$lang['strnoserversupplied'] = 'No server supplied!';
+	$lang['strbadpgdumppath'] = 'Export error: Failed to execute pg_dump (given path in your conf/config.inc.php : %s). Please, fix this path in your configuration and relog.';
+	$lang['strbadpgdumpallpath'] = 'Export error: Failed to execute pg_dumpall (given path in your conf/config.inc.php : %s). Please, fix this path in your configuration and relog.';
 
 	// Tables
 	$lang['strtable'] = 'Table';
